zeromq: A modern networking library
===================================

Description
-----------

A modern networking library. Also known as 0mq or zmq. The same API is
provided by http://www.crossroads.io, though we currently use the
http://www.zeromq.org implementation.

License
-------

LGPLv3+


Upstream Contact
----------------

http://www.zeromq.org

Dependencies
------------

A working compiler.


Special Update/Build Instructions
---------------------------------

N/A
